import { ApolloError, QueryResult } from '@apollo/client';
/**
 * @see https://package.elm-lang.org/packages/krisajenkins/remotedata/latest/
 */
export declare type RemoteData<D> = Initialized | Pending | Failure | Success<D>;
export interface Initialized {
    readonly tag: 'Initialized';
}
export interface Pending {
    readonly tag: 'Pending';
}
export interface Failure {
    readonly tag: 'Failure';
    error: Required<Pick<QueryResult, 'error'>>['error'];
}
export interface Success<A> {
    readonly tag: 'Success';
    data: A;
}
export declare const initialized: <T = never>() => RemoteData<T>;
export declare const pending: <T = never>() => RemoteData<T>;
export declare const failure: <T = never>(error: ApolloError) => RemoteData<T>;
export declare const success: <D = never>(data: D) => RemoteData<D>;
export declare const isInitialized: <D = never>(rd: RemoteData<D>) => rd is Pending;
export declare const isLoading: <D = never>(rd: RemoteData<D>) => rd is Pending;
export declare const isFailure: <D = never>(rd: RemoteData<D>) => rd is Failure;
export declare const isSuccess: <D = never>(rd: RemoteData<D>) => rd is Success<D>;
export declare const fold: <T, D>(initialized: () => T, pending: () => T, failure: (error: ApolloError) => T, success: (data: D) => T) => (_: RemoteData<D>) => T;
export declare const map: <T, D>(f: (a: T) => D, fa: RemoteData<T>) => RemoteData<D>;
//# sourceMappingURL=rd.d.ts.map